aboutsummaryrefslogtreecommitdiffstats
path: root/src/onaptests/configuration/basic_network_nomulticloud_settings.py
diff options
context:
space:
mode:
authormrichomme <morgan.richomme@orange.com>2021-02-01 17:26:42 +0100
committermrichomme <morgan.richomme@orange.com>2021-02-01 17:39:08 +0100
commitba1faac52b28f752516ab075a5bda56058548e49 (patch)
tree5bc9fc301758fa60a4da73bcca0a8e7b4970d57b /src/onaptests/configuration/basic_network_nomulticloud_settings.py
parent5021508f4b6f8bf2bb6ef890b4bb960dc144484b (diff)
[TESTS] cleanup tests and remove reference to ubuntu16
the basic_vm test was historically called ubuntu16... as we are now delaing more with ubuntu18 or ubuntu20, the reference to the version16 is a bit old - Replace ubuntu16 by basic_vm - Use ubuntu20 instead of Ubuntu16 - Replace onap.small by m1.small to be natively compatible with any Openstack (default flavor) Issue-ID: TEST-299 Signed-off-by: mrichomme <morgan.richomme@orange.com> Change-Id: I69f573354c87c44c10581861450d48244db0c7df
Diffstat (limited to 'src/onaptests/configuration/basic_network_nomulticloud_settings.py')
-rw-r--r--src/onaptests/configuration/basic_network_nomulticloud_settings.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/onaptests/configuration/basic_network_nomulticloud_settings.py b/src/onaptests/configuration/basic_network_nomulticloud_settings.py
index fd7c561..cc22601 100644
--- a/src/onaptests/configuration/basic_network_nomulticloud_settings.py
+++ b/src/onaptests/configuration/basic_network_nomulticloud_settings.py
@@ -6,11 +6,11 @@ from yaml import load
import onaptests.utils.exceptions as onap_test_exceptions
from .settings import * # pylint: disable=W0614
""" Specific ubuntu16 without multicloud."""
# pylint: disable=bad-whitespace
# The ONAP part
-SERVICE_DETAILS="Onboarding, distribution and instanitation of asic Network using à la carte"
+SERVICE_DETAILS="Onboarding, distribution and instantiation of Basic Network using à la carte"
SERVICE_COMPONENTS="SDC, DMAAP, AAI, SO, SDNC"
USE_MULTICLOUD = False
# Set ONLY_INSTANTIATE to true to run an instantiation without repeating
@@ -6,11 +6,11 @@ from yaml import load
import onaptests.utils.exceptions as onap_test_exceptions
from .settings import * # pylint: disable=W0614
-""" Specific ubuntu16 without multicloud."""
+""" Specific Basic Network without multicloud."""
# pylint: disable=bad-whitespace
# The ONAP part